import { __awaiter, __decorate, __rest } from "tslib";
import { Connect, ResourceType, defaultDatasourceConfig, } from '@genesislcap/foundation-comms';
import { renderers } from '@genesislcap/foundation-forms';
import { showNotification, showNotificationDialog } from '@genesislcap/foundation-notifications';
import { LifecycleMixin } from '@genesislcap/foundation-utils';
import { attr, customElement, DOM, FASTElement, observable, volatile, } from '@microsoft/fast-element';
import * as changeCase from 'change-case';
import { CrudMenuPosition, ActionsMenuStyle, ModalFormType, CrudAction } from '../types';
import { getErrorFormat, logger } from '../utils';
import { getSearchBarColumnsConfig, getSearchBarMetaConfig } from '../utils/search-bar-utils';
import { styles } from './entities.styles';
import { defaultHeader, searchBarHeader, template } from './entities.template';
/**
 * Main class which defines the entity management functionality
 *
 * @remarks
 *
 * Connects to a backend resource and wraps up a grid which is populated
 * with entities from that resource. The different interactions that the user
 * can perform with the entities can be configured, examples being able to
 * update and delete entities.
 *
 * @public
 *
 * @example
 * Example of using the entity management system to handle counterparties
 * ```
 * <entity-management
 *   resourceName="ALL_COUNTERPARTYS"
 *   title="Counterparty Management"
 *   updateEvent="EVENT_COUNTERPARTY_MODIFY"
 *   deleteEvent="EVENT_COUNTERPARTY_DELETE"
 *   createEvent="EVENT_COUNTERPARTY_INSERT"
 * ></entity-management>
 * ```
 * Where:<br />
 * - the title of the grid is `Counterparty Management`<br />
 * - the name of the resource in the database to manage is `ALL_COUNTERPARTYS`<br />
 * - the name of the event handler for update events is `EVENT_COUNTERPARTY_MODIFY`<br />
 * - the name of the event handler for create events is `EVENT_COUNTERPARTY_INSERT`<br />
 * - the name of the event handler for delete events is `EVENT_COUNTERPARTY_DELETE`<br />
 *
 * @fires request-changed - Fired when the request is changed
 * @fires criteria-changed - Fired when the criteria is changed
 * @fires create-entity - Fired when an entity is created
 * @fires edit-entity - Fired when an entity is edited
 * @fires delete-entity - Fired when an entity is deleted
 *
 * Bubbled events from the child entity-list component
 * @fires submit-failure - Fired when there is an error in a create, edit or delete operation
 * @fires submit-success - Fired when a create, edit or delete operation is completed successfully
 * @fires rowClick - Fired when a row is clicked
 * @fires rowDblClick - Fired when a row is double clicked
 * @fires contextMenu - Fired when a row is right clicked
 * @fires rowSelected - Fired when a row is selected
 */
let EntityManagement = class EntityManagement extends LifecycleMixin(FASTElement) {
    constructor() {
        super(...arguments);
        /**
         * Name of the design system prefix that will be used in renderers.
         * @public
         */
        this.prefix = 'zero';
        /**
         * Whether to use the `applyTransactionAsync` function for *add* transactions
         * @remarks Defaults to false
         * @internal
         */
        this.asyncAdd = false;
        /**
         * Whether to use the `applyTransactionAsync` function for *remove* transactions
         * @remarks Defaults to false
         * @internal
         */
        this.asyncRemove = false;
        /**
         * Whether to use the `applyTransactionAsync` function for *update* transactions
         * @remarks Defaults to true
         * @internal
         */
        this.asyncUpdate = true;
        /**
         * This attribute allows you to change row-selection to 'single' or 'multiple' which will allow you to select single or multiple rows.
         * @remarks Defaults to single
         * @public
         */
        this.rowSelection = 'single';
        /**
         * If false, will disable cell flashing for all cells by default, unless otherwise defined in custom colDef
         * @remarks Defaults to true
         * @public
         */
        this.enableCellFlashing = false;
        /**
         * If true, will enable row flashing for all rows for `add` transactions
         * @public
         */
        this.enableRowFlashing = false;
        /**
         * If set to 'server' it will enable Server-Side Row Model and use `grid-pro-server-side-datasource` for the grid of the `entity-list` sub-component.
         * By default `grid-pro-client-side-datasource` will be used.
         * @public
         */
        this.datasourceType = 'client';
        /**
         * The configuration which is used when interacting with the resource on the backend
         *
         * @remarks
         *
         * Handles the configuration such as how many rows of entities to fetch at a time
         * @public
         */
        this.datasourceConfig = defaultDatasourceConfig.options;
        /**
         * Array with renderers used by foundation-forms
         * @public
         */
        this.formRenderers = renderers;
        /**
         * @internal
         */
        this.editModalVisible = false;
        /**
         * Hides edit button
         * @public
         */
        this.hideEdit = false;
        /**
         * Hides delete button
         * @public
         */
        this.hideDelete = false;
        /**
         * This attribute controls whether to enable the search-bar.
         * @public
         */
        this.enableSearchBar = false;
        /**
         * Determines where the modal dialog will appear on screen
         * @public
         */
        this.modalPosition = 'right';
        /**
         * Determines where the buttons will appear
         * @public
         */
        this.crudMenuPosition = CrudMenuPosition.Column;
        /**
         * Determines the style of the buttons
         * @public
         */
        this.crudMenuStyle = ActionsMenuStyle.Default;
        /**
         * The label of the crud action menu
         */
        this.crudActionMenuName = '⋮';
        /**
         * Updates the reference to the current entity stored in the class. Added as an event listener on the class when receiving the `rowSelected` event.
         *
         * @param e - CustomEvent which contains data about the selected entity. If the row is not selected then the reference will be set to an empty object.
         * @internal
         */
        this.selectEntity = (e) => {
            this.selectedEntity = e.detail.node.isSelected() ? e.detail.data : {};
        };
    }
    editModalVisibleChanged() {
        if (this.editEntityModal) {
            if (this.editModalVisible) {
                this.editEntityModal.show();
            }
            else {
                this.editEntityModal.close();
            }
        }
    }
    /**
     * The helper function to determine the title of the modal form or button based on the action or type
     * @param actionOrType - The crud action or modal form type
     * @internal
     */
    getTitleBasedOnActionOrType(actionOrType) {
        switch (actionOrType) {
            case ModalFormType.Create:
                return `Add ${this.entityLabel || ''}`;
            case ModalFormType.Update:
                return `Edit ${this.entityLabel || ''}`;
            case CrudAction.Delete:
                return `Delete ${this.entityLabel || ''}`;
            default:
                return '';
        }
    }
    /**
     * Getter for the title of the modal form
     * @internal
     */
    get modalFormTitle() {
        return this.getTitleBasedOnActionOrType(this.modalFormType);
    }
    /**
     * Determines whether the button edit should be hidden in the column
     * @internal
     */
    get shouldHideEditInColumn() {
        return this.hideEdit || this.crudMenuPosition !== CrudMenuPosition.Column;
    }
    /**
     * Determines whether the button delete should be hidden in the column
     * @internal
     */
    get shouldHideDeleteInColumn() {
        return this.hideDelete || this.crudMenuPosition !== CrudMenuPosition.Column;
    }
    /**
     * Determines whether there is a selected entity
     * @internal
     */
    get hasSelectedEntity() {
        return !!(this.selectedEntity && Object.keys(this.selectedEntity).length > 0);
    }
    /**
     * Checks if a slot contains any content.
     *
     * @param slotName - The name of the slot to check.
     * @returns True if the slot has content, otherwise false.
     * @internal
     */
    hasContentInSlot(slotName) {
        var _a;
        const slot = (_a = this.shadowRoot) === null || _a === void 0 ? void 0 : _a.querySelector(`slot[name=${slotName}]`);
        return !!(slot === null || slot === void 0 ? void 0 : slot.assignedNodes().length);
    }
    /**
     * Set up the web component
     * @internal
     */
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            _super.connectedCallback.call(this);
            this.addEventListener('rowSelected', this.selectEntity);
            this.addEventListener('delete-entity', this.deleteEntity);
            this.addEventListener('create-entity', this.createEntity);
            this.addEventListener('edit-entity', this.editEntity);
            this.addEventListener('read-entity', this.readEntity);
            this.addEventListener('criteria-changed', this.criteriaChanged);
            this.addEventListener('request-changed', this.requestChanged);
            this.addEventListener('submit', this.submitErrorHandler);
            this.addEventListener('submit-failure', this.submitFailureNotification);
            if (!this.searchBarConfig) {
                this.getDefaultSearchBarConfig();
            }
            if (this.crudMenuStyle.includes('actions-')) {
                this.generateCrudActionsMenu();
            }
        });
    }
    /**
     * @internal
     */
    disconnectedCallback() {
        const _super = Object.create(null, {
            disconnectedCallback: { get: () => super.disconnectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const shouldRunDisconnect = this.shouldRunDisconnect;
            DOM.queueUpdate(() => {
                if (!shouldRunDisconnect || !this.isConnected)
                    return;
                _super.disconnectedCallback.call(this);
                this.removeEventListener('rowSelected', this.selectEntity);
                this.removeEventListener('delete-entity', this.deleteEntity);
                this.removeEventListener('create-entity', this.createEntity);
                this.removeEventListener('edit-entity', this.editEntity);
                this.removeEventListener('read-entity', this.readEntity);
                this.removeEventListener('criteria-changed', this.criteriaChanged);
                this.removeEventListener('request-changed', this.requestChanged);
                this.removeEventListener('submit', this.submitErrorHandler);
                this.removeEventListener('submit-failure', this.submitFailureNotification);
            });
        });
    }
    /**
     * Gets the default searchBarConfig if the user has not created their own.
     * @internal
     */
    getDefaultSearchBarConfig() {
        return __awaiter(this, void 0, void 0, function* () {
            const meta = yield this.connect
                .getMetadata(this.resourceName)
                .catch((e) => logger.error(`Metadata Fetch failed for ${this.resourceName}:`, e));
            if (!meta) {
                return;
            }
            const changeCaseByType = changeCase[this.headerCaseType];
            if (this.columns) {
                this.searchBarConfig = getSearchBarColumnsConfig(this.columns, meta, changeCaseByType);
            }
            else {
                this.searchBarConfig = getSearchBarMetaConfig(meta, changeCaseByType);
            }
        });
    }
    /**
     * Override the deepClone method to ensure that observable attributes are cloned
     * @internal
     */
    deepClone() {
        const copy = super.deepClone();
        copy.createFormUiSchema = structuredClone(this.createFormUiSchema);
        copy.datasourceConfig = structuredClone(this.datasourceConfig);
        copy.gridOptions = {};
        if (this.gridOptions) {
            Object.keys(this.gridOptions).forEach((key) => {
                if (typeof this.gridOptions[key] === 'function') {
                    copy.gridOptions[key] = this.gridOptions[key].bind(copy);
                }
                else {
                    copy.gridOptions[key] = structuredClone(this.gridOptions[key]);
                }
            });
        }
        copy.modalFormType = structuredClone(this.modalFormType);
        copy.editModalVisible = structuredClone(this.editModalVisible);
        copy.formResourceName = structuredClone(this.formResourceName);
        copy.formUiSchema = structuredClone(this.formUiSchema);
        copy.updateFormUiSchema = structuredClone(this.updateFormUiSchema);
        copy.defaultEntityValues = structuredClone(this.defaultEntityValues);
        // this.columns[number] and this.formRenderers[number] might contain a function, so can't use structuredClone
        copy.columns = this.columns ? [...this.columns].map((x) => (Object.assign({}, x))) : this.columns;
        copy.formRenderers = this.formRenderers
            ? [...this.formRenderers].map((x) => (Object.assign({}, x)))
            : this.formRenderers;
        return copy;
    }
    /**
     * Event handler for when the user submits the action for the currently open form, either editing or adding the entity
     *
     * @internal
     */
    submitEntityChanges() {
        return __awaiter(this, void 0, void 0, function* () {
            this.handleNotify(this.modalFormType);
            this.closeModal();
        });
    }
    /**
     * Show the entity create form
     * Sets the initial value on the form to be defaultEntityValues if present.
     * @internal
     */
    createEntity() {
        this.modalFormType = ModalFormType.Create;
        this.formUiSchema = this.createFormUiSchema;
        this.formResourceName = this.createEvent;
        this.editedEntity = Object.assign({}, this.defaultEntityValues);
        this.editModalVisible = true;
    }
    /**
     * Opens the model to edit an entity. Added as an event listener on the class when receiving the `edit-entity` event.
     *
     * @param e - CustomEvent where `e.detail` is the entity to edit.
     * @internal
     */
    editEntity({ detail }) {
        return __awaiter(this, void 0, void 0, function* () {
            this.modalFormType = ModalFormType.Update;
            this.formUiSchema = this.updateFormUiSchema;
            this.formResourceName = this.updateEvent;
            if (detail) {
                const { ROW_REF } = detail, formData = __rest(detail, ["ROW_REF"]);
                this.editedEntity = formData;
                if (this.readEventFn) {
                    const readEntityReq = yield this.readEventFn(formData);
                    this.editedEntity = Object.assign(Object.assign({}, this.editedEntity), readEntityReq);
                }
                else if (this.readEvent) {
                    const readEventReq = yield this.connect.request(this.readEvent, {
                        REQUEST: formData,
                    });
                    this.editedEntity = Object.assign(Object.assign({}, this.editedEntity), readEventReq.REPLY[0]);
                }
            }
            else {
                this.editedEntity = Object.assign({}, this.defaultEntityValues);
            }
            this.editModalVisible = true;
        });
    }
    readEntity(e) {
        this.modalFormType = ModalFormType.Read;
        this.readonly = true;
        this.editEntity(e);
    }
    /**
     * @internal
     */
    closeModal() {
        this.modalFormType = null;
        this.readonly = false;
        this.editModalVisible = false;
    }
    /**
     * @internal
     */
    get headerTempalate() {
        return this.enableSearchBar ? searchBarHeader(this.prefix) : defaultHeader(this.prefix);
    }
    // TODO: seems like a dead code, needs further review if it's needed
    /**
     * @internal
     */
    get isServerSideDatasource() {
        return this.datasourceType === 'server';
    }
    /**
     * @internal
     */
    searchChanged(event) {
        const selectedOptions = event.detail;
        if (!selectedOptions.length) {
            this.$emit('request-changed', null);
            this.$emit('criteria-changed', null);
        }
        if (selectedOptions.find((x) => x.resourceType === ResourceType.REQUEST_SERVER)) {
            this.searchBarReqServer(selectedOptions);
        }
        else {
            this.searchBarDataserver(selectedOptions);
        }
    }
    searchBarReqServer(options) {
        const requestOptions = options.reduce((_, c) => ({ [c.field]: c.term }), {});
        this.$emit('request-changed', requestOptions);
    }
    searchBarDataserver(options) {
        const criteriaBuilder = options
            .map((option) => {
            const { field, term, createCriteria } = option;
            if (createCriteria) {
                return createCriteria(field, term);
            }
            else {
                logger.debug('Cannot convert search option into criteria', option);
                return;
            }
        })
            .filter((x) => x)
            .join(' && ');
        this.$emit('criteria-changed', criteriaBuilder);
    }
    requestChanged(e) {
        this.datasourceConfig = Object.assign(Object.assign({}, this.datasourceConfig), { request: e.detail });
    }
    criteriaChanged(e) {
        this.datasourceConfig = Object.assign(Object.assign({}, this.datasourceConfig), { criteria: e.detail });
    }
    submitFailureNotification(e) {
        e.detail.errors.forEach((submitFailureError) => {
            if (submitFailureError.CODE === 'OPTIMISTIC_CONCURRENCY_ERROR') {
                showNotification({
                    title: 'Warning',
                    body: 'You’re editing an old revision. Please close the form and try editing again',
                    config: {
                        snackbar: {
                            type: 'error',
                        },
                    },
                }, this.prefix);
            }
            else {
                showNotification({
                    title: 'Error submitting form',
                    body: (submitFailureError.CODE + ': ' + submitFailureError.TEXT).toString(),
                    config: {
                        snackbar: {
                            type: 'error',
                        },
                    },
                }, this.prefix);
            }
        });
    }
    submitErrorHandler(e) {
        var _a;
        (_a = e.detail.errors) === null || _a === void 0 ? void 0 : _a.forEach((error) => {
            showNotification({
                title: 'Error submitting form',
                body: error.message,
                config: {
                    snackbar: {
                        type: 'error',
                    },
                },
            }, this.prefix);
        });
    }
    /**
     * Handler for deleting the entity. Added as an event listener on the class when receiving the `delete-entity` event.
     *
     * @param e - CustomEvent where `e.detail` contains data to update the selectedEntity reference with the entity to delete.
     * @internal
     */
    deleteEntity(e) {
        return __awaiter(this, void 0, void 0, function* () {
            this.selectedEntity = e.detail;
            this.showDeleteConfirmation();
        });
    }
    /**
     * @internal
     */
    confirmDelete() {
        return __awaiter(this, void 0, void 0, function* () {
            const schema = yield this.connect.getJSONSchema(this.deleteEvent);
            const DETAILS = {};
            if (typeof schema.INBOUND.properties.DETAILS !== 'boolean') {
                const requiredFields = Object.keys(schema.INBOUND.properties.DETAILS.properties);
                if (requiredFields) {
                    requiredFields.forEach((property) => {
                        DETAILS[property] = this.selectedEntity[property];
                    });
                    const deleteReq = yield this.connect.commitEvent(this.deleteEvent, {
                        DETAILS,
                    });
                    this.handleNotify(CrudAction.Delete, deleteReq.ERROR);
                    if (!deleteReq.ERROR) {
                        this.clearSelectedEntity();
                    }
                }
                else {
                    logger.error('No required fields found for delete event', this.deleteEvent);
                }
            }
        });
    }
    showDeleteConfirmation() {
        showNotificationDialog({
            title: 'Confirm Delete',
            body: 'Do you really want to delete this entity?',
            dialog: {
                dismissingAction: { label: 'Dismiss', action: () => this.clearSelectedEntity() },
                confirmingActions: [{ label: 'Confirm', action: () => this.confirmDelete() }],
            },
        }, this.prefix);
    }
    /**
     * Emit the CRUD event for the selected entity
     * @param action - the action to emit
     * @internal
     */
    emitCrud(action) {
        this.$emit(`${action}-entity`, this.selectedEntity);
    }
    /**
     * Show notifications after CRUD operations (success or failure).
     * @internal
     */
    handleNotify(type, requestError) {
        const notificationCloseTimeout = 5000;
        if (requestError) {
            logger.error(requestError);
            requestError.forEach((err) => {
                showNotification({
                    title: err.CODE,
                    body: getErrorFormat(err),
                    config: {
                        toast: { type: 'warning', autoClose: true, closeTimeout: notificationCloseTimeout },
                    },
                }, this.prefix);
            });
        }
        else {
            const label = this.entityLabel ? this.entityLabel : 'Entity';
            const titleAndBody = {
                [ModalFormType.Create]: {
                    title: `${label} Added`,
                    body: `The ${label} was successfully added`,
                },
                [ModalFormType.Update]: {
                    title: `${label} Updated`,
                    body: `The ${label} was successfully updated`,
                },
                [CrudAction.Delete]: {
                    title: `${label} Deleted`,
                    body: `The ${label} was successfully deleted`,
                },
            }[type] || { title: '', body: '' };
            showNotification(Object.assign(Object.assign({}, titleAndBody), { config: {
                    toast: { type: 'success', autoClose: true, closeTimeout: notificationCloseTimeout },
                } }), this.prefix);
        }
    }
    /**
     * Clear the selected entity
     * @internal
     */
    clearSelectedEntity() {
        this.selectedEntity = null;
    }
    /**
     * Helper to generate the CRUD actions menu
     *
     * @internal
     */
    generateCrudActionsMenu() {
        const actionsMenu = document.createElement(`${this.prefix}-actions-menu`);
        actionsMenu.setAttribute('part', 'actions-menu');
        actionsMenu.style.width = '100%';
        actionsMenu.name = this.crudActionMenuName;
        actionsMenu.isVertical = this.crudMenuStyle === ActionsMenuStyle.ActionsVertical;
        actionsMenu.actions = [
            {
                name: 'Add',
                callback: () => this.emitCrud('create'),
            },
        ];
        if (this.updateEvent && !this.hideEdit) {
            actionsMenu.actions.push({
                name: 'Edit',
                callback: () => this.emitCrud('edit'),
                isDisabled: () => !this.hasSelectedEntity,
            });
        }
        if (this.deleteEvent && !this.hideDelete) {
            actionsMenu.actions.push({
                name: 'Delete',
                callback: () => this.emitCrud('delete'),
                isDisabled: () => !this.hasSelectedEntity,
            });
        }
        DOM.queueUpdate(() => {
            var _a;
            (_a = this.crudMenuWrapper) === null || _a === void 0 ? void 0 : _a.appendChild(actionsMenu);
        });
    }
    /**
     * The event handler for when the selection changes in the grid.
     * @internal
     */
    selectionChanged(event) {
        const selectedRows = event.detail.api.getSelectedRows();
        if (selectedRows && selectedRows.length !== 0) {
            this.selectedEntity = selectedRows[0];
        }
        else {
            this.selectedEntity = null;
        }
    }
};
__decorate([
    Connect
], EntityManagement.prototype, "connect", void 0);
__decorate([
    attr({ attribute: 'design-system-prefix' })
], EntityManagement.prototype, "prefix", void 0);
__decorate([
    attr
], EntityManagement.prototype, "resourceName", void 0);
__decorate([
    attr
], EntityManagement.prototype, "readEvent", void 0);
__decorate([
    observable
], EntityManagement.prototype, "readEventFn", void 0);
__decorate([
    attr({ mode: 'boolean' })
], EntityManagement.prototype, "readonly", void 0);
__decorate([
    attr
], EntityManagement.prototype, "updateEvent", void 0);
__decorate([
    attr
], EntityManagement.prototype, "deleteEvent", void 0);
__decorate([
    attr
], EntityManagement.prototype, "createEvent", void 0);
__decorate([
    attr
], EntityManagement.prototype, "title", void 0);
__decorate([
    attr
], EntityManagement.prototype, "entityLabel", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'async-add' })
], EntityManagement.prototype, "asyncAdd", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'async-remove' })
], EntityManagement.prototype, "asyncRemove", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'async-update' })
], EntityManagement.prototype, "asyncUpdate", void 0);
__decorate([
    attr({ attribute: 'row-selection' })
], EntityManagement.prototype, "rowSelection", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'enable-cell-flashing' })
], EntityManagement.prototype, "enableCellFlashing", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'enable-row-flashing' })
], EntityManagement.prototype, "enableRowFlashing", void 0);
__decorate([
    attr({ attribute: 'datasource-type' })
], EntityManagement.prototype, "datasourceType", void 0);
__decorate([
    attr({ attribute: 'persist-column-state-key' })
], EntityManagement.prototype, "persistColumnStateKey", void 0);
__decorate([
    observable
], EntityManagement.prototype, "gridOptions", void 0);
__decorate([
    observable
], EntityManagement.prototype, "columns", void 0);
__decorate([
    observable
], EntityManagement.prototype, "datasourceConfig", void 0);
__decorate([
    observable
], EntityManagement.prototype, "formUiSchema", void 0);
__decorate([
    observable
], EntityManagement.prototype, "createFormUiSchema", void 0);
__decorate([
    observable
], EntityManagement.prototype, "updateFormUiSchema", void 0);
__decorate([
    observable
], EntityManagement.prototype, "formResourceName", void 0);
__decorate([
    observable
], EntityManagement.prototype, "formRenderers", void 0);
__decorate([
    observable
], EntityManagement.prototype, "selectedEntity", void 0);
__decorate([
    observable
], EntityManagement.prototype, "editedEntity", void 0);
__decorate([
    observable
], EntityManagement.prototype, "defaultEntityValues", void 0);
__decorate([
    observable
], EntityManagement.prototype, "submitting", void 0);
__decorate([
    observable
], EntityManagement.prototype, "modalFormType", void 0);
__decorate([
    observable
], EntityManagement.prototype, "editModalVisible", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'size-columns-to-fit' })
], EntityManagement.prototype, "sizeColumnsToFit", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'enable-filter-bar' })
], EntityManagement.prototype, "enableFilterBar", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'hide-edit' })
], EntityManagement.prototype, "hideEdit", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'hide-delete' })
], EntityManagement.prototype, "hideDelete", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'enable-search-bar' })
], EntityManagement.prototype, "enableSearchBar", void 0);
__decorate([
    attr({ attribute: 'header-case-type' })
], EntityManagement.prototype, "headerCaseType", void 0);
__decorate([
    observable
], EntityManagement.prototype, "searchBarConfig", void 0);
__decorate([
    attr({ attribute: 'modal-position' })
], EntityManagement.prototype, "modalPosition", void 0);
__decorate([
    attr({ attribute: 'crud-menu-position' })
], EntityManagement.prototype, "crudMenuPosition", void 0);
__decorate([
    attr({ attribute: 'crud-menu-style' })
], EntityManagement.prototype, "crudMenuStyle", void 0);
__decorate([
    attr({ attribute: 'crud-action-menu-name' })
], EntityManagement.prototype, "crudActionMenuName", void 0);
__decorate([
    volatile
], EntityManagement.prototype, "headerTempalate", null);
EntityManagement = __decorate([
    customElement({
        name: 'entity-management',
        template,
        styles,
    })
], EntityManagement);
export { EntityManagement };
